@@ -40,7 +40,7 @@ Currently supported interfaces are:
 """
 
 
-__version__ = "0.3"
+__version__ = "0.4"
 
 
 #from pymlab import config
@@ -50,5 +50,5 @@ __version__ = "0.3"
 
 
 if __name__ == "__main__":
-	print __doc__
+	print(__doc__)
     #main()
